#
# spec file for package python-jaraco.functools
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-jaraco.functools
Version:        4.1.0
Release:        1.2
Summary:        Tools to work with functools
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/jaraco/jaraco.functools
Source0:        https://files.pythonhosted.org/packages/source/j/jaraco.functools/jaraco_functools-%{version}.tar.gz
BuildRequires:  %{python_module jaraco.classes}
BuildRequires:  %{python_module more-itertools}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 56}
BuildRequires:  %{python_module setuptools_scm >= 3.4.1}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-more-itertools
BuildArch:      noarch
# SECTION test and docs
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module rst.linker >= 1.9}
# /SECTION
%python_subpackages

%description
jaraco.functools Tools for working with functools.
Additional functools in the spirit of stdlib’s functools.

%prep
%setup -q -n jaraco_functools-%{version}
sed -i 's/--flake8//' pytest.ini
sed -i 's/--black --cov//' pytest.ini
rm -rf jaraco.functools.egg-info

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_function_throttled - can randomly fail
%pytest -k 'not test_function_throttled'

%files %{python_files}
%license LICENSE
%doc docs/*.rst README.rst NEWS.rst
%{python_sitelib}/jaraco/functools
%{python_sitelib}/jaraco.functools-%{version}.dist-info

%changelog
* Sun Sep 29 2024 Dirk Müller <dmueller@suse.com>
- update to 4.1.0:
  * Added chainable decorator.
* Tue Jun  4 2024 Dirk Müller <dmueller@suse.com>
- update to 4.0.1:
  * No significant changes.
* Tue Apr  9 2024 Dirk Müller <dmueller@suse.com>
- remove jaraco.packaging as it is only needed for docs
* Tue Jan  2 2024 Dirk Müller <dmueller@suse.com>
- update to 4.0.0:
  * Added splat function.
  * Removed deprecated 'call_aside'.
  * Enhanced type hints and declare the package as typed.
    Module is now a package.
  * Restored type checking and repaired broken exclusion.
  * Require Python 3.8 or later.
  * Added bypass_unless and bypass_when and identity.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Sun Mar 26 2023 Dirk Müller <dmueller@suse.com>
- update to 3.6.0:
  * #21: Renamed ``call_aside`` to ``invoke``, deprecating
    ``call_aside``.
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v3.5.2
  * Refreshed packaging.
* Wed Sep 14 2022 Matej Cepl <mcepl@suse.com>
- Tidelift is a good and interesting company, but we really don’t
  need to have python-jaraco.tidelit as a dependency.
* Wed Aug 31 2022 Torsten Gruner <simmphonie@opensuse.org>
- update to 3.5.1
  * Packaging refresh
  * Enrolled with Tidelift
* Sun Mar 27 2022 Dirk Müller <dmueller@suse.com>
- update to 3.5.0:
  * #19: Add type annotations to ``method_cache``.
  * Require Python 3.7.
  * ``apply`` now uses ``functools.wraps`` to ensure docstring
  * passthrough.
  * #18: In method_cache, support cache_clear before cache
  * is initialized.
  * Refreshed package metadata.
  * Switched to PEP 420 for ``jaraco`` namespace.
  * Added ``except_`` decorator.
* Wed Dec  2 2020 Benjamin Greiner <code@bnavigator.de>
- compile cache for all python3 flavors
  gh#openSUSE/python-rpm-macros#66
* Thu Sep 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.0.1:
  [#14]: Removed unnecessary compatibility libraries in testing.
* Sat Mar 14 2020 Tomáš Chvátal <tchvatal@suse.com>
- Femove leftover py2 dependencies
* Mon Mar  9 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 3.0.0
  * Require Python 3.6 or later.
* Wed Aug 21 2019 Tomáš Chvátal <tchvatal@suse.com>
- Skip another test that is randomly failing
* Wed Apr 17 2019 Matej Cepl <mcepl@suse.com>
- Skip method_cache doctest test (gh#jaraco/jaraco.functools#12).
* Tue Feb 26 2019 John Vandenberg <jayvdb@gmail.com>
- Add LICENSE
- Compile manually due to switch to pkgutil namespace technique
- Add fdupes
- Re-instate use of --doctest-modules to increase coverage
- Remove undesirable build dependency pytest-sugar
- Add missing runtime dependency on python-jaraco.base
- Add missing runtime dependency on more-itertools
- Add explicit build dependency on python-six
- Update to v2.0
  * Switch to pkgutil namespace technique for the ``jaraco`` namespace.
* Tue Aug 28 2018 dmueller@suse.com
- enable tests
* Thu Aug 23 2018 dheidler@suse.de
- Initial Package for v1.20
